@@ -217,6 +217,10 @@ wl_display_flush_clients(struct wl_display *display);
 void
 wl_display_destroy_clients(struct wl_display *display);
 
+void
+wl_display_set_default_max_buffer_size(struct wl_display *display,
+				       size_t max_buffer_size);
+
 struct wl_client;
 
 typedef void (*wl_global_bind_func_t)(struct wl_client *client, void *data,
@@ -279,6 +283,13 @@ wl_display_set_global_filter(struct wl_display *display,
 const struct wl_interface *
 wl_global_get_interface(const struct wl_global *global);
 
+uint32_t
+wl_global_get_name(const struct wl_global *global,
+                   const struct wl_client *client);
+
+uint32_t
+wl_global_get_version(const struct wl_global *global);
+
 struct wl_display *
 wl_global_get_display(const struct wl_global *global);
 
@@ -327,6 +338,14 @@ struct wl_listener *
 wl_client_get_destroy_listener(struct wl_client *client,
 			       wl_notify_func_t notify);
 
+void
+wl_client_add_destroy_late_listener(struct wl_client *client,
+				    struct wl_listener *listener);
+
+struct wl_listener *
+wl_client_get_destroy_late_listener(struct wl_client *client,
+				    wl_notify_func_t notify);
+
 struct wl_resource *
 wl_client_get_object(struct wl_client *client, uint32_t id);
 
@@ -350,6 +369,19 @@ wl_client_for_each_resource(struct wl_client *client,
                             wl_client_for_each_resource_iterator_func_t iterator,
                             void *user_data);
 
+typedef void (*wl_user_data_destroy_func_t)(void *data);
+
+void
+wl_client_set_user_data(struct wl_client *client,
+			void *data,
+			wl_user_data_destroy_func_t dtor);
+
+void *
+wl_client_get_user_data(struct wl_client *client);
+
+void
+wl_client_set_max_buffer_size(struct wl_client *client, size_t max_buffer_size);
+
 /** \class wl_listener
  *
  * \brief A single listener for Wayland signals
@@ -481,6 +513,9 @@ wl_signal_emit(struct wl_signal *signal, void *data)
 		l->notify(l, data);
 }
 
+void
+wl_signal_emit_mutable(struct wl_signal *signal, void *data);
+
 typedef void (*wl_resource_destroy_func_t)(struct wl_resource *resource);
 
 /*
@@ -639,10 +674,11 @@ wl_display_init_shm(struct wl_display *display);
 uint32_t *
 wl_display_add_shm_format(struct wl_display *display, uint32_t format);
 
+WL_DEPRECATED
 struct wl_shm_buffer *
 wl_shm_buffer_create(struct wl_client *client,
 		     uint32_t id, int32_t width, int32_t height,
-		     int32_t stride, uint32_t format) WL_DEPRECATED;
+		     int32_t stride, uint32_t format);
 
 void
 wl_log_set_handler_server(wl_log_func_t handler);
